# CHANGELOG - Controle de alterações

Documentação das principais alterações deste repositório.
Baseado na filosofia [Mantenha um Changelog](https://keepachangelog.com/pt-BR/1.0.0/).

### [0.5] - 2024-07-10

- Melhora timeout de carregamento inicial da página See[#14](https://github.com/automatiza-mg/pythomate/issues/14) (retira wait(active)).

### [0.5] - 2024-07-10

- Fecha automate após execução do fluxo See [#15](https://github.com/automatiza-mg/pythomate/issues/15).
- Melhora timeout de carregamento inicial da página See[#14](https://github.com/automatiza-mg/pythomate/issues/14).
- Melhora fluxo click ok para fluxos com variáveis de entrada See [#12](https://github.com/automatiza-mg/pythomate/issues/12).

### [0.4] - 2024-05-22

- Aumenta timoute para execução Power Automate - See [#11](https://github.com/automatiza-mg/pythomate/issues/11#issuecomment-2125428514).
- Melhora documentação - See [#11](https://github.com/automatiza-mg/pythomate/issues/11#issuecomment-2125428514).

### [0.3] - 2024-05-22

- Corrige erro de não clicar em Meus fluxos no menu inicial - See [#11](https://github.com/automatiza-mg/pythomate/issues/11).

### [0.2] - 2023-11-10

- Publicação primeiro comando `pythomate run automate <nome-fluxo>`.

### [0.1] - 2023-10-16

- Publicação estrutura inicial necessária para funcionamento do pacote. Sem nenhuma função implementada.
